@@ -5,14 +5,13 @@
 #define TREEITEM_H
 
 #include <QObject>
+#include <QOpcUaEUInformation>
 #include <QOpcUaNode>
+#include <QOpcUaRange>
+
 #include <memory>
 
-QT_BEGIN_NAMESPACE
-
 class OpcUaModel;
-class QOpcUaRange;
-class QOpcUaEUInformation;
 
 class TreeItem : public QObject
 {
@@ -78,6 +77,4 @@ QString TreeItem::numberArrayToString(const QList<T> &vec) const
     return list;
 }
 
-QT_END_NAMESPACE
-
 #endif // TREEITEM_H
